# The pywwt Frontend Module

This NPM package contains the JavaScript code implementing the frontend of the
[pywwt] data visualization tool, as used in [Jupyter/JupyterLab][jupyter]. For
more information, see [the pywwt docs][pywwt]. As such, this package is mostly a
pywwt implementation detail. To write your own WWT-based web apps, check out
[documentation for the WWT web stack][web-docs].

[pywwt]: https://pywwt.readthedocs.io/
[jupyter]: https://jupyter.org/
[web-docs]: https://docs.worldwidetelescope.org/webgl-reference/latest/

pywwt is built on the [AAS][aas] [WorldWide Telescope][wwt] (WWT) system. WWT is
a free, open-source tool for visually exploring humanity’s scientific
understanding of the Universe. WWT is brought to you by the non-profit [American
Astronomical Society][aas] (AAS), the major organization of professional
astronomers in North America, and the [.NET Foundation][dnf].

[pywwt]: https://pywwt.readthedocs.io/
[aas]: https://aas.org/
[wwt]: http://www.worldwidetelescope.org/home
[dnf]: https://dotnetfoundation.org/

